<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <location filename="../fileops.cpp" line="132"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Cílový adresář neexistuje</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="136"/>
        <source>Move Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="137"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="153"/>
        <source>Copying</source>
        <translation>Kopíruje se</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <location filename="../fileops.cpp" line="244"/>
        <source>Stop</source>
        <translation>Přerušit</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="199"/>
        <source>Copying file %1/%2</source>
        <translation>Kopíruje se soubor %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="243"/>
        <source>Moving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="276"/>
        <source>Moving file %1/%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="114"/>
        <source>Remove Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="115"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Jste si jisti, že chcete z disku odstranit %n soubor?</numerusform>
            <numerusform>Jste si jisti, že chcete z disku odstranit %n soubory?</numerusform>
            <numerusform>Jste si jisti, že chcete z disku odstranit %n souborů?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="31"/>
        <source>File Operations Plugin</source>
        <translation>Modul pro operace se soubory</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>About File Operations Plugin</source>
        <translation>O modulu pro operace se soubory</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Modul Qmmp pro operace se soubory</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Změnit klávesovou zkratku</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Stlačte kombinaci kláves, kterou chcete přiřadit</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Vyčistit</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Nastavení operací se soubory</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Povoleno</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Operace</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Text v nabídce</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Cíl:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Vzor jména:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>Nová akce</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="220"/>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="222"/>
        <source>Album Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="223"/>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="224"/>
        <source>Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="225"/>
        <source>Two-digit Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="230"/>
        <source>Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>File Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="226"/>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="227"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="228"/>
        <source>Composer</source>
        <translation>Skladatel</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="229"/>
        <source>Duration</source>
        <translation>Délka</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="233"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="234"/>
        <source>Condition</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="247"/>
        <source>Choose a directory</source>
        <translation>Vyberte adresář</translation>
    </message>
</context>
</TS>
